% bLegengre   Legendre function.
%    P = bLegendre(z,n) computes all Legendre polynomials 
%    of degree 0,1,...,n, evaluated for each element
%    of z.  n must be a scalar integer and z must contain complex values. 
%
% Examples: 
%   x = linspace(-1,1,100);
%   fx = bLegendre(x,5);
%   plot(x,fx);

function val = bLegendre(z,n)

z = z(:);
val = ones(size(z,1),n+1);
if n > 0
  val(:,2) = z(:);
end
for k = 1:n-1
  val(:,k+2) = ((2*k+1)*z.*val(:,k+1)-k*val(:,k))./(k+1);
end